==> haskell-ini-0.4.2-198.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-13Nwba0BN2Y17jOOEO0UfW
key:                  ini-0.4.2-13Nwba0BN2Y17jOOEO0UfW
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  43761b04b2b431314fe5d2516e1011dc
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-13Nwba0BN2Y17jOOEO0UfW
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.4.2-199-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-CzH5cgvXkfKJT0UR2lY8Qv
key:                  ini-0.4.2-CzH5cgvXkfKJT0UR2lY8Qv
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  6c140d0fc1b9e6c97dff8c5ad590ff11
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-CzH5cgvXkfKJT0UR2lY8Qv
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
